==> haskell-monad-memo-0.5.4-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-memo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-memo
version:              0.5.4
visibility:           public
id:                   monad-memo-0.5.4-4zZNWxp3XeFA4HEFQs0Bc8
key:                  monad-memo-0.5.4-4zZNWxp3XeFA4HEFQs0Bc8
license:              BSD-3-Clause
maintainer:           eduard.sergeev@gmail.com
author:               Eduard Sergeev
homepage:             https://github.com/EduardSergeev/monad-memo
synopsis:             Memoization monad transformer
description:
    Memoization monad transformer supporting most of the standard monad transformers and a range of memoization cache types: from default pure maps to extremely fast mutable vectors

    To add memoization behaviour to a monadic function:

    1) Add '\''Control.Monad.Memo.memo'\'' combinator at the point when memoization is required (i.e. recursive call)

    >import Control.Monad.Memo
    >
    >fibm 0 = return 0
    >fibm 1 = return 1
    >fibm n = do
    >  n1 <- memo fibm (n-1)
    >  n2 <- memo fibm (n-2)
    >  return (n1+n2)

    2) Use appropriate /*eval*/ or /*run*/ function to evaluate resulting `MonadMemo` monad:

    >startEvalMemo (fibm 100)

    See detailed description and examples: "Control.Monad.Memo"

category:             Control, Monad
abi:                  0ebe063e408427097dccfbe42032c696
exposed:              True
exposed-modules:
    Control.Monad.Memo Control.Monad.Memo.Array
    Control.Monad.Memo.Array.Instances Control.Monad.Memo.Class
    Control.Monad.Memo.Vector Control.Monad.Memo.Vector.Expandable
    Control.Monad.Memo.Vector.Instances
    Control.Monad.Memo.Vector.Unsafe Control.Monad.Trans.Memo.Map
    Control.Monad.Trans.Memo.ReaderCache Control.Monad.Trans.Memo.State
    Control.Monad.Trans.Memo.StateCache Data.MapLike
    Data.MapLike.Instances Data.MaybeLike Data.MaybeLike.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-memo-0.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-memo-0.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-memo-0.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-memo
hs-libraries:         HSmonad-memo-0.5.4-4zZNWxp3XeFA4HEFQs0Bc8
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    primitive-0.9.1.0-GChnkqMWBe7B15Z0K3IGlf transformers-0.5.6.2
    vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:   /usr/share/doc/haskell-monad-memo/html/monad-memo.haddock
haddock-html:         /usr/share/doc/haskell-monad-memo/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-memo-0.5.4-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-memo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-memo
version:              0.5.4
visibility:           public
id:                   monad-memo-0.5.4-8ptN6osT9oNAPVQzDwJbUR
key:                  monad-memo-0.5.4-8ptN6osT9oNAPVQzDwJbUR
license:              BSD-3-Clause
maintainer:           eduard.sergeev@gmail.com
author:               Eduard Sergeev
homepage:             https://github.com/EduardSergeev/monad-memo
synopsis:             Memoization monad transformer
description:
    Memoization monad transformer supporting most of the standard monad transformers and a range of memoization cache types: from default pure maps to extremely fast mutable vectors

    To add memoization behaviour to a monadic function:

    1) Add '\''Control.Monad.Memo.memo'\'' combinator at the point when memoization is required (i.e. recursive call)

    >import Control.Monad.Memo
    >
    >fibm 0 = return 0
    >fibm 1 = return 1
    >fibm n = do
    >  n1 <- memo fibm (n-1)
    >  n2 <- memo fibm (n-2)
    >  return (n1+n2)

    2) Use appropriate /*eval*/ or /*run*/ function to evaluate resulting `MonadMemo` monad:

    >startEvalMemo (fibm 100)

    See detailed description and examples: "Control.Monad.Memo"

category:             Control, Monad
abi:                  71fc562087d960cff222255921e35eed
exposed:              True
exposed-modules:
    Control.Monad.Memo Control.Monad.Memo.Array
    Control.Monad.Memo.Array.Instances Control.Monad.Memo.Class
    Control.Monad.Memo.Vector Control.Monad.Memo.Vector.Expandable
    Control.Monad.Memo.Vector.Instances
    Control.Monad.Memo.Vector.Unsafe Control.Monad.Trans.Memo.Map
    Control.Monad.Trans.Memo.ReaderCache Control.Monad.Trans.Memo.State
    Control.Monad.Trans.Memo.StateCache Data.MapLike
    Data.MapLike.Instances Data.MaybeLike Data.MaybeLike.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-memo-0.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-memo-0.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-memo-0.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-memo
hs-libraries:         HSmonad-memo-0.5.4-8ptN6osT9oNAPVQzDwJbUR
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    primitive-0.9.1.0-3MsYNTRfRHtDQ9eN2n6le5 transformers-0.5.6.2
    vector-0.13.2.0-52P7Ozt5w3I6hi4WvheJB9

haddock-interfaces:   /usr/share/doc/haskell-monad-memo/html/monad-memo.haddock
haddock-html:         /usr/share/doc/haskell-monad-memo/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
